@@ -5,11 +5,10 @@ This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions and classes.
 """
 import sys
+
 import objc
 import CoreFoundation
 import Quartz
-import CoreText._manual
-
 from CoreText import _metadata
 
 sys.modules["CoreText"] = mod = objc.ObjCLazyModule(
@@ -26,14 +25,13 @@ sys.modules["CoreText"] = mod = objc.ObjCLazyModule(
         "__loader__": globals().get("__loader__", None),
         "objc": objc,
     },
-    (CoreFoundation, Quartz, CoreText._manual),
+    (CoreFoundation, Quartz),
 )
 
-import CoreText._manual as m
+import CoreText._manual as m  # isort:skip # noqa: E402
 
 for nm in dir(m):
     setattr(mod, nm, getattr(m, nm))
 
-import sys
 
 del sys.modules["CoreText._metadata"]
